
``fslpy``
=========


The ``fslpy`` package is a collection of utilities and data abstractions used
within `FSL <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki>`_ and by
|fsleyes_apidoc|_.


The top-level Python package for ``fslpy`` is called ``fsl``.  It is broadly
split into the following sub-packages:


.. autosummary::

   fsl.data
   fsl.utils
   fsl.scripts
   fsl.transform
   fsl.version
   fsl.wrappers


.. toctree::
   :hidden:

   self
   fsl
   contributing
   changelog
